@@ -116,6 +116,11 @@ class Leg(object):
     __leg_minAngle = 0
     __leg_maxAngle = 180
 
+    @property
+    def angle(self):
+        """ Returns the leg angle """
+        return self.__leg_angle
+
     def __init__(self, name, channel, leg_minangle, leg_maxangle, invert):
         # Initialises the leg object
         try:
@@ -622,14 +627,14 @@ class SmarsRobot(object):
         """ returns a list of limbs and measurements """
         telemetry = []
         chan = Channel()
-        telemetry.append(["left_leg_front", self.__legs[chan.LEFT_LEG_FRONT].__leg_angle])
-        telemetry.append(["right_leg_front", self.__legs[chan.RIGHT_LEG_FRONT].__leg_angle])
-        telemetry.append(["left_leg_back", self.__legs[chan.LEFT_LEG_BACK].__leg_angle])
-        telemetry.append(["right_leg_back", self.__legs[chan.RIGHT_LEG_BACK].__leg_angle])
-        telemetry.append(["left_foot_front", self.__legs[chan.LEFT_FOOT_FRONT].__leg_angle])
-        telemetry.append(["right_foot_front", self.__legs[chan.RIGHT_FOOT_FRONT].__leg_angle])
-        telemetry.append(["left_foot_back", self.__legs[chan.LEFT_FOOT_BACK].__leg_angle])
-        telemetry.append(["right_foot_back", self.__legs[chan.RIGHT_FOOT_BACK].__leg_angle])
+        telemetry.append(["left_leg_front", self.__legs[chan.LEFT_LEG_FRONT].angle])
+        telemetry.append(["right_leg_front", self.__legs[chan.RIGHT_LEG_FRONT].angle])
+        telemetry.append(["left_leg_back", self.__legs[chan.LEFT_LEG_BACK].angle])
+        telemetry.append(["right_leg_back", self.__legs[chan.RIGHT_LEG_BACK].angle])
+        telemetry.append(["left_foot_front", self.__legs[chan.LEFT_FOOT_FRONT].angle])
+        telemetry.append(["right_foot_front", self.__legs[chan.RIGHT_FOOT_FRONT].angle])
+        telemetry.append(["left_foot_back", self.__legs[chan.LEFT_FOOT_BACK].angle])
+        telemetry.append(["right_foot_back", self.__legs[chan.RIGHT_FOOT_BACK].angle])
         return telemetry
 
 class CommandHistory(object):
